.stm_news{
  position: relative;
  .news_list{
    list-style: none;
    padding: 0;
    margin: 0 -15px;
    font-size: 0;
    &.posts_per_row_3{
      li{
        width: 33%;
      }
    }
    &.posts_per_row_2{
      li{
        width: 50%;
      }
    }
    &.posts_per_row_1{
      li{
        width: 100%;
      }
    }
    li{
      display: inline-block;
      vertical-align: top;
      width: 25%;
      padding: 0 15px;
      margin-bottom: 30px;
      font-size: 13px;
      .image{
        margin: 0 0 30px;
        img{
          display: block;
          max-width: 100%;
          height: auto;
        }
        a{
          position: relative;
          display: block;
          &:before{
            content: '';
            position: absolute;
            left: 0;
            top: 0;
            right: 0;
            bottom: 0;
            background: rgba(#000, .6);
            @include transition();
            opacity: 0;
          }
          &:after{
            content: "\e920";
            @include theme_icons();
            @include transition();
            position: absolute;
            left: 50%;
            top: 50%;
            margin: -15px 0 0 -15px;
            color: #fff;
            font-size: 30px;
            opacity: 0;
          }
          &:hover{
            &:before, &:after{
              opacity: 1;
            }
          }
        }
      }
      h5{
        margin-bottom: 17px;
        padding-top: 0;
        &:before{
          content: '';
          display: block;
          width: 47px;
          height: 5px;
          background: $stm_third_color;
          margin: 0 0 20px;
        }
        a{
          color: $stm_base_color;
          &:hover{
            color: #222;
            text-decoration: none;
          }
        }
      }
      .date{
        position: relative;
        font-size: 13px;
        padding: 0 0 0 23px;
        &:before{
          content: "\f017";
          @include fa();
          color: $stm_third_color;
          position: absolute;
          left: 0;
          top: 1px;
          font-size: 15px;
        }
      }
    }
  }
}