.testimonials_carousel{
  position: relative;
  margin: 0 -20px;
  &.disable_carousel{
    font-size: 0;
    .testimonial{
      padding: 0 20px;
      margin: 0 0 45px;
      display: inline-block;
      vertical-align: top;
      font-size: 14px;
    }
    &.per_row_2{
      .testimonial{
        width: 50%;
      }
    }
    &.per_row_3{
      .testimonial{
        width: 33%;
        .image{
          float: none;
          max-width: inherit;
          margin: 0 0 20px;
        }
      }
    }
  }
  .testimonial{
    position: relative;
    padding: 0 20px;
    .image{
      float: left;
      margin: 0 30px 0 0;
      max-width: 255px;
      a{
        position: relative;
        display: block;
        &:before{
          content: '';
          position: absolute;
          left: 0;
          top: 0;
          right: 0;
          bottom: 0;
          background: rgba(#000, .6);
          @include transition();
          opacity: 0;
        }
        &:after{
          content: "\e920";
          @include theme_icons();
          @include transition();
          position: absolute;
          left: 50%;
          top: 50%;
          margin: -15px 0 0 -15px;
          color: #fff;
          font-size: 30px;
          opacity: 0;
        }
        &:hover{
          &:before, &:after{
            opacity: 1;
          }
        }
      }
      img{
        display: block;
        max-width: 100%;
        height: auto;
      }
    }
    .info{
      overflow: hidden;
      h4{
        color: $stm_base_color;
        margin-bottom: 6px;
        line-height: 22px;
        padding-top: 0;
        a{
          color: $stm_base_color;
          @include transition();
          &:hover{
            color: #222;
            text-decoration: none;
          }
        }
      }
      .position, .company{
        font-family: "Montserrat", sans-serif;
        font-weight: 700;
        color: #777777;
        line-height: 18px;
      }
      .company{
        margin: 0 0 24px;
      }
      p{
        color: #222222;
        line-height: 22px;
        margin: 0;
      }
    }
  }
}

.testimonials_carousel {
  &.style_2 {
    margin: 0 -15px;
    .item {
      position: relative;
      padding: 0 15px;

      .testimonial{
        background: #f5f5f5;
        position: relative;
        padding: 28px 28px 27px;
        margin: 0 0 21px;
        &:before{
          content: "\e90b";
          @include theme_icons();
          font-size: 48px;
          color: $stm_third_color;
          position: absolute;
          right: 0;
          bottom: 0;
          width: 60px;
          height: 40px;
          overflow: hidden;
        }
        &:after{
          content: '';
          position: absolute;
          left: 65px;
          bottom: -30px;
          width: 30px;
          height: 33px;
          background: url("../../images/testimonials_before.png") no-repeat 0 0;
          background-size: 15px 18px;
        }
        p{
          margin: 0;
          font: {
            size: 14px;
          }
          line-height: 26px;
          color: #222;
        }

        &:before{
          bottom: 0;
          right: 1px;
        }

        &:after{
          background-image: url("../../images/testimonials_before_2.png");
        }
      }

      .testimonial-info{
        position: relative;
        @include cleaner();
        .testimonial-image{
          max-width: 50px;
          display: table-cell;
          vertical-align: middle;
          img{
            max-width: 100%;
            height: auto;
            overflow: hidden;
            @include border-radius(100%);
          }
        }
        .testimonial-text{
          display: table-cell;
          vertical-align: middle;
          padding: 0 0 0 15px;
          .name{
            color: #222;
            line-height: 20px;
            font: {
              family: "Montserrat", sans-serif;
              size: 14px;
              weight: 700;
            }
          }
          .company{
            font-size: 14px;
            color: #808080;
            line-height: 20px;
            font-style: italic;
          }
        }
      }
    }
  }
}

.testimonials_carousel {
  &.style_3 {
    .testimonial_inner {
      padding: 20px;
      background: #fff;
      @include cleaner;

      .image {
        margin-right: 20px;
        width: 174px;
      }

      p {
        margin-bottom: 17px;
        color: #222;
        line-height: 22px;
      }

      h6 {
        padding-top: 0;
        margin-bottom: 3px;
        letter-spacing: 0;

        a {
          color: $stm_base_color;
          @include transition(color);

          &:hover,
          &:focus {
            text-decoration: none;
          }

          &:hover {
            color: #222;
          }
        }
      }

      .position {
        font-size: 13px;
        letter-spacing: -0.01em;
        font-weight: 400;
        color: #777;
      }
    }
  }
}