.consulting-rev-title{
  font-size: 60px;
  line-height: 60px;
  color: #fff;
  font-family: "Montserrat", sans-serif;
  font-weight: 700;
  letter-spacing: -0.06em;
}

.consulting-rev-title-2{
  font-size: 36px;
  line-height: 42px;
  color: #222222;
  font-family: "Montserrat", sans-serif;
  font-weight: 700;
  letter-spacing: -0.06em;
}

.consulting-rev-title-3{
  font-size: 45px;
  line-height: 45px;
  color: #222222;
  font-family: "Montserrat", sans-serif;
  font-weight: 700;
  letter-spacing: -0.06em;
}

.consulting-rev-title-icon{
  font-size: 72px;
  color: $stm_secondary_color;
  padding-left: 1px;
}

.consulting-rev-text{
  font-weight: 400;
  font-family: "Montserrat", sans-serif;
  color: #fff;
  line-height: 32px;
  font-size: 24px;
  letter-spacing: -0.02em;
}

.consulting-rev-text-2{
  color: #222222;
  line-height: 22px;
  font-size: 14px;
}

.tp-caption{
  .button{
    transition: all .3s ease !important;
    margin-right: 16px;
  }
}

// Blue - Overlay
.baseColorOverlay.tp-caption {
  background: rgba( $stm_base_color, .3 ) !important;
}

body .tparrows{
  width: 45px;
  height: 45px;
  background: none;
  border: 3px solid #bac1c6;
  @include transition();
  &:hover{
    background: $stm_base_color;
    border-color: $stm_base_color;
    &:before{
      color: #fff;
    }
  }
  &.tp-leftarrow{
    &:before{
      content: "\f053";
      padding: 0 3px 0 0;
    }
  }
  &.tp-rightarrow{
    &:before{
      content: "\f054";
      padding: 0 0 0 3px;
    }
  }
  &:before{
    @include fa();
    font-size: 19px;
    line-height: 40px;
    color: #bac1c6;
  }
}

body{
  .tp-bullets{
    .tp-bullet{
      width: 4px;
      height: 4px;
      background: $stm_secondary_color;
      box-sizing: content-box;
      margin: 2px;
      padding: 0;
      @include border-radius(50%);
      &.selected{
        background: $stm_base_color;
        padding: 2px;
        margin: 0;
      }
    }
  }
}