.comment-info {
  ul {
    list-style: none;
    padding: 0;
    margin: 0 0 20px;
    li {
      position: relative;
      padding: 0 0 0 20px;
      margin: 0 0 4px;
    }
    &.type_1 li:before{
      content: '\f00c';
      top: 4px;
    }
    &.type_2 li:before {
      content: '\f14a';
      top: 3px;
      font-size: 14px;
    }
  }
  ol {
    margin: 0 0 20px;
    padding: 0;
    list-style-position: inside;
    li{
      position: relative;
      padding: 0 0 0 20px;
      margin: 0 0 4px;
    }
  }
}

.comments-title {
  position: relative;
  font-weight: 700;
  text-transform: lowercase;
  margin-bottom: 20px;
  &:after {
    display: none;
  }
}

ul.comment-list {
  position: relative;
  margin: 0 0 40px;
  padding: 0;
  li {
    list-style: none;
    border-top: 1px solid #dddddd;
    padding: 30px 0 0;
    margin: 0 0 30px;
  }
  .comment {
    .vcard {
      float: left;
      margin: 0 32px 0 0;
      width: 87px;
      img {
        max-width: 100%;
        height: auto;
      }
    }
    .comment-info {
      overflow: hidden;
    }
    .comment-author {
      float: left;
      font-family: "Montserrat", sans-serif;
      font-weight: 600;
      color: #333333;
    }
    .comment-meta {
      float: right;
      font-size: 11px;
      color: #aaaaaa;
      text-transform: uppercase;
      font-weight: 600;
      margin: 0 0 15px 0;
      a {
        display: inline-block;
        vertical-align: middle;
        color: #aaaaaa;
        &:hover {
          color: $stm_secondary_color;
          text-decoration: none;
        }
        &:before {
          content: "/";
          display: inline-block;
          vertical-align: baseline;
          margin: 0 7px 0 5px;
          color: #dddddd;
        }
        &:first-child:before {
          display: none;
        }
      }
    }
    .comment-text {
      clear: both;
      p {
        line-height: 22px;
      }
      *:last-child {
        margin-bottom: 0;
      }
    }
  }
  .children {
    margin: 29px 0 0 30px;
    padding: 0;
    > li {
      position: relative;
      padding: 30px 0 0;
      margin: 0 0 30px;
      border-top: 1px solid #dddddd;
      &:before {
        content: '';
        position: absolute;
        left: 66px;
        top: -9px;
        background: url("../../images/comment_before.png") no-repeat 0 0;
        width: 15px;
        height: 9px;
      }
    }
  }
}

.comment-respond {
  margin: 40px 0 0 0;
}

.comment-reply-title {
  margin: 0 0 19px;
  font-size: 20px;
  text-transform: lowercase;
  &:after{
    display: none;
  }
}

.bypostauthor {
}

.comment-reply-title:before {
  margin: 0 0 22px 0;
}

.comment-awaiting-moderation {
  display: block;
  color: $stm_secondary_color;
  font-weight: 700;
  text-transform: lowercase;
  margin: 10px 0 0;
}

.comment-info table {
  width: 100%;
  margin: 0 0 40px;
}

.comment-info table {
  td, th {
    border: 1px solid #e9e9e9;
    padding: 5px 10px;
  }
}

.comment-form{
  .form-submit{
    display: none;
  }
}

.comment-info {
  ul ul, ol ol {
    margin: 10px 0 20px 20px;
  }
}