.wpb_gallery_slidesslick_slider_2.slider_main {
  margin: 0 0 40px 0;
}

.wpb_gallery_slides_navslick_slider_2.slider_nav {
  .slick-slide {
    margin: 0 5px;
    img {
      cursor: pointer;
    }
  }
  .slick-slide-wr {
    position: relative;
  }
  .stm-slick-active .slick-slide-wr:after {
    content: '';
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    background: rgba(0, 0, 0, 0.5);
  }
  margin: 0 -5px;
}

.wpb_gallery_slidesslick_slider_2.slider_main {
  .slick_next {
    right: 20px;
    top: auto;
    margin: 0;
    bottom: 20px;
    opacity: 0;
    -webkit-transition: opacity 0.2s linear;
    -moz-transition: opacity 0.2s linear;
    -ms-transition: opacity 0.2s linear;
    -o-transition: opacity 0.2s linear;
    transition: opacity 0.2s linear;
  }
  .slick_prev {
    left: auto;
    right: 75px;
    top: auto;
    bottom: 20px;
    margin: 0;
    opacity: 0;
    -webkit-transition: opacity 0.2s linear;
    -moz-transition: opacity 0.2s linear;
    -ms-transition: opacity 0.2s linear;
    -o-transition: opacity 0.2s linear;
    transition: opacity 0.2s linear;
  }
  &:hover {
    .slick_prev, .slick_next {
      opacity: 0.5;
    }
    .slick_prev:hover, .slick_next:hover {
      opacity: 1;
      transition: none;
    }
  }
  .image_title {
    position: absolute;
    bottom: 0;
    left: 0;
    background: rgba(0, 0, 0, 0.35);
    width: 100%;
    padding: 30px 200px 30px 28px;
    font-size: 16px;
    color: #ffffff;
    opacity: 0;
    -webkit-transition: opacity 0.2s linear;
    -moz-transition: opacity 0.2s linear;
    -ms-transition: opacity 0.2s linear;
    -o-transition: opacity 0.2s linear;
    transition: opacity 0.2s linear;
  }
  &:hover .image_title {
    opacity: 1;
  }
  .slider_info {
    position: absolute;
    right: 138px;
    bottom: 31px;
    font-size: 14px;
    color: #fff;
    opacity: 0;
    -webkit-transition: opacity 0.2s linear;
    -moz-transition: opacity 0.2s linear;
    -ms-transition: opacity 0.2s linear;
    -o-transition: opacity 0.2s linear;
    transition: opacity 0.2s linear;
  }
  &:hover .slider_info {
    opacity: 1;
  }
  .slider_info {
    span {
      color: $stm_base_color;
    }
    em {
      font-style: normal;
    }
  }
}