.stats_counter {
  position: relative;
  .icon {
    float: left;
    color: $stm_base_color;
    margin: 0 12px 0 0;
  }
  h3:after {
    display: none;
  }
  h3 {
    color: #fff;
    margin: 0 0 14px;
    font-size: 50px;
    letter-spacing: 0;
    white-space: nowrap;
  }
  .counter_title {
    clear: both;
    color: #fff;
    font-family: "Montserrat", sans-serif;
  }
}