.page_404 {
  .bottom{
    position: fixed;
    bottom: 0;
    left: 0;
    right: 0;
    h1{
      padding: 0;
      margin: 0 0 0 -11px;
      font-size: 230px;
      line-height: 132px;
      color: $stm_base_color;
      &:after{
        display: none;
      }
    }
    .bottom_wr{
      padding: 70px 95px;
      background: $stm_base_color;
      .media{
        h3{
          color: #fff;
          padding: 0;
          margin: 0;
          &:after{
            display: none;
          }
        }
      }
    }
  }
}