.stm_contact {
  position: relative;
  margin: 0 0 27px 0;
  .stm_contact_image{
    float: left;
    max-width: 87px;
    margin: 0 23px 0 0;
    img{
      display: block;
      max-width: 100%;
      height: auto;
    }
  }
  .stm_contact_info{
    overflow: hidden;
    h5{
      padding: 0;
      margin: 0 0 7px;
      line-height: 16px;
    }
    .stm_contact_job{
      font-family: "Montserrat", sans-serif;
      font-size: 13px;
      margin: 0 0 9px;
    }
    .stm_contact_row{
      font-size: 13px;
      margin: 0 0 4px;
      &:last-child{
        margin: 0;
      }
      a{
        color: $stm_base_color;
      }
    }
  }
}