.info_box {
  position: relative;
  margin: 0 0 30px;
  &.align_center{
    text-align: center;
  }
  h4 {
    font-weight: 700;
    font-family: "Montserrat", sans-serif;
    letter-spacing: -.04em;
    color: $stm_base_color;
    margin: 0 0 13px;
    &:before {
      display: none;
    }
  }
  p {
    margin: 0 0 14px;
    line-height: 22px;
    color: #222222;
  }
  .read_more {
    text-transform: lowercase;
    font: {
      family: "Montserrat", sans-serif;
      weight: 700;
      size: 13px;
    }
    transition: color 0.2s linear;
    color: $stm_base_color;
    .stm_icon {
      margin: 2px 0 0 14px;
      font-size: 12px;
      vertical-align: middle;
      color: $stm_third_color;
      @include transition(color);
    }
    span {
      vertical-align: middle;
      line-height: 13px;
      letter-spacing: -.2px;
    }
    &:hover,
    &:focus {
      text-decoration: none;
    }
    &:hover {
      color: $stm_secondary_color;
    }
  }
  ul {
    list-style: none;
    padding: 0;
    margin: 0;
    li{
      position: relative;
      padding: 0 0 0 20px;
      margin: 0 0 4px;
      &:before{
        content: "\f054";
        position: absolute;
        left: 0;
        top: 5px;
        display: inline-block;
        vertical-align: top;
        font: normal normal normal 14px/1 FontAwesome;
        font-size: 10px;
        color: $stm_base_color;
        text-rendering: auto;
        -webkit-font-smoothing: antialiased;
        -moz-osx-font-smoothing: grayscale;
        transform: translate(0, 0);
      }
    }
  }
  &.style_2{
    background: rgba(#fff,0.95);
    @include transition(background);
    &:hover{
      background: #fff;
    }

    h4 {
      margin-bottom: 15px;
    }

    p {
      margin-bottom: 18px;
      line-height: 18px;
      color: #777777;
    }

    .read_more {
      color: $stm_base_color;
      .stm_icon {
        color: $stm_third_color;
      }
      &:hover {
        color: $stm_secondary_color;
        .stm_icon {
          color: $stm_secondary_color;
        }
      }
    }
  }
  &.style_3{
    overflow: hidden;
    &:hover{
      .info_box_text{
        padding-top: 38px;
        top: 0;
      }
    }
    .info_box_text{
      position: absolute;
      left: 0;
      top: 163px;
      right: 0;
      bottom: 0;
      background: rgba($stm_base_color, .9);
      padding: 17px 30px 0;
      @include transition();
      .title{
        margin-bottom: 8px;
        @include cleaner();
        .icon{
          color: $stm_third_color;
          font-size: 40px;
          display: table-cell;
          vertical-align: middle;
          padding: 0 12px 0 0;
        }
        h6{
          color: #fff;
          display: table-cell;
          vertical-align: middle;
          padding-top: 0;
          margin: 0;
          font-weight: 700;
        }
      }
      p {
        margin: 0 0 20px;
        color: #fff;
        padding-left: 55px;
        font-size: 13px;
        line-height: 24px;
      }
      .read_more {
        text-transform: lowercase;
        transition: color 0.2s linear;
        color: $stm_third_color;
        padding-left: 55px;
        .stm_icon {
          margin: 2px 0 0 5px;
          font-size: 12px;
          vertical-align: middle;
          color: $stm_third_color;
        }
        span {
          vertical-align: middle;
          line-height: 13px;
        }
        &:hover {
          color: #fff;
          text-decoration: none;
          .stm_icon{
            color: $stm_third_color;
          }
        }
      }
    }
    .info_box_image{
      margin: 0;
    }
  }
  &.style_4 {
    h4 {
      color: #222;
      letter-spacing: 0;
      margin-bottom: 10px;
    }

    .info_box_image {
      position: relative;
      margin-bottom: 4px;

      &:before {
        content: "";
        position: absolute;
        z-index: 1;
        top: 0; left: 0;
        width: 100%;
        height: 100%;
        opacity: 0;
        background: rgba( #000, .2 );
        @include transition(opacity);

      }

      &:after {
        content: "";
        position: absolute;
        bottom: 0;
        left: 0;
        background: $stm_third_color;
        width: 0;
        height: 5px;
        z-index: 2;
        @include transition();
      }
    }

    p {
      color: #888;
      font-size: 13px;
      margin-bottom: 0;
      @include transition();
    }

    .read_more {
      position: absolute;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      color: transparent;
      font: 0/0 sans-serif;
    }

    &:hover {
      .info_box_image {
        &:after {
          width: 100%;
        }
        &:before {
          opacity: 1;

        }
      }

      p {
        color: #222;
      }
    }
  }
  &.style_5 {
    border: 4px solid $stm_secondary_color;
    padding: 27px 25px 20px 27px;
    @include transition(border-color, .4s, ease);

    &:hover {
      border-color: $stm_base_color;
    }

    h3 {
      line-height: 30px;
      letter-spacing: -0.04em;
      padding-top: 10px;
      margin-bottom: 20px;

      &:after {
        margin-top: 16px;
      }
    }

    p {
      margin-bottom: 32px;
      font-size: 13px;
    }

    .read_more {
      color: $stm_base_color;
      font-weight: 600;
      letter-spacing: 0.04em;

      .stm_icon {
        margin-left: 10px;
      }
    }
  }
}

.info_box {
  &.style_6 {
    background: #fff;
    padding: 40px;
    @include transition();
    .info_box_text {
      .title {
        margin-bottom: 10px;
      }
      .icon {
        width: 55px;
        display: table-cell;
        vertical-align: middle;
        i {
          font-size: 32px;
          color: $stm_secondary_color;
        }
      }
      h5 {
        display: table-cell;
        vertical-align: middle;
        font-weight: 400;
        padding-top: 0;
        margin-bottom: 0;
        letter-spacing: -.05em;
      }

      p {
        padding-left: 55px;
        font-size: 13px;
        line-height: 18px;
        color: #777;
        margin-bottom: 17px;
      }

      .read_more {
        padding-left: 55px;
        text-transform: none;

        &:hover {
          color: $stm_third_color;
        }

        .stm_icon {
          margin-left: 10px;
        }
      }
    }

    &:hover {
      box-shadow: 0 5px 10px rgba(#000, 0.2);
    }
  }
}

.info_box_image {
  position: relative;
  margin: 0 0 3px;
  img {
    max-width: 100%;
    height: auto;
  }
}