@media only screen and (max-width: 1440px) {
  body {
    .tparrows{
      &.tp-leftarrow{
        transform: none !important;
        -webkit-transform: none !important;
        -moz-transform: none !important;
        left: 0 !important;
        margin: -22px 0 0 0 !important;
      }
      &.tp-rightarrow{
        transform: none !important;
        -webkit-transform: none !important;
        -moz-transform: none !important;
        left: auto !important;
        right: 0 !important;
        margin: -22px 0 0 0 !important;
      }
    }
    &.boxed_layout{
      .tparrows{
        &.tp-leftarrow{
          left: 18px !important;
        }
        &.tp-rightarrow{
          right: 18px !important;
        }
      }
      .slick_prev{
        left: -40px;
      }
      .slick_next{
        right: -40px;
      }
    }
  }
}

@media only screen and (max-width: 1199px) {
  body.header_style_7 {
    .header_side_wrapper {
      .side_nav {
        margin-top: 42px;
      }
    }
  }
  body {
    &.header_style_6 {
      .header_top {
        .top_nav {
          .top_nav_wrapper {
            > ul {
              margin-right: -15px;
              > li {
                > a {
                  padding: 10px 15px;
                }

                &.menu-item-has-children > a:after {
                  right: 0;
                }
              }
            }
          }
        }
      }

      #lang_sel {
        margin-right: 30px;
      }

      .top_bar_contacts > li {
        margin-right: 30px;
      }
    }
  }
  body.header_style_4 {
    .header_top {
      .icon_text {
        margin-left: 45px;
        &:last-child {
          margin-left: 0;
        }
        &.big {
          margin-left: 45px;
        }
      }
    }
  }

  .stm_services_tabs  {
    .services_categories {
      ul li a {
        padding: 14.5px 15.3px;
      }
    }
  }

  .stm_contacts_widget.style_2 {
    ul li:not(:last-child) {
      margin-right: 20px;
    }
  }
}

@media only screen and (max-width: 1024px) {
  .vc_grid-item.blog .vc_gitem-post-data-source-post_date {
    display: none;
  }
  .header_socials {
    margin: 0 0 0 40px;
  }
  #wrapper {
    padding-bottom: 0 !important;
  }
  #footer {
    position: relative;
    width: auto;
    bottom: auto;
  }
  .contact_col aside.widget {
    padding-top: 38px !important;
    padding-bottom: 30px !important;
  }
  .top_nav {
    .top_nav_wrapper > ul, .main_menu_nav > ul {
      padding: 0 15px;
    }
  }
  .icon_button {
    font-size: 10px;
  }
  .top_bar .top_bar_info li:before {
    margin: 0 15px;
  }
  .top_nav .icon_text{
    padding: 0 0 0 20px;
    margin: 18px 20px 0 0;
  }
  body .vc_row.fixed_bg{
    background-attachment: scroll;
  }
  .top_bar_info_wr .top_bar_info li{
    padding: 5px;
    font-size: 12px;
  }
  .top_bar_info_wr .top_bar_info_switcher .active{
    padding: 14px 35px 16px 15px;
    min-width: 140px;
  }
  body.header_style_2 .header_top .top_nav .top_nav_wrapper>ul>li>a, body.header_style_2 .header_top .top_nav .main_menu_nav>ul>li>a{
    padding-left: 10px;
    padding-right: 10px;
  }
  body.header_style_2 .header_top .top_nav .header_socials{
    margin: 0 0 0 20px;
  }
  body.header_style_2 .header_top .top_nav .header_socials a{
    margin-left: 14px;
  }
  body.header_style_4 .top_nav .top_nav_wrapper>ul>li>a{
    padding-left: 20px;
    padding-right: 20px;
  }
  .info_box.style_3 .info_box_text{
    top: 122px;
  }
  .info_box.style_3:hover .info_box_text{
    padding-top: 18px;
  }
  .info_box.style_3 .info_box_text p{
    padding-left: 0;
    margin-bottom: 10px;
  }
  .info_box.style_3 .info_box_text .read_more{
    padding-left: 0;
  }
  body.header_style_7 {
    margin-left: auto;
    .stm-revslider-wrapper {
      padding-left: 0 !important;
    }
    #header {
      .header_side, .top_nav {
        display: none;
      }
    }
    .mobile_header {
      display: block;
      .header_socials {
        margin: 0;
        float: right;
      }
      #stm_wpml_lang_switcher {
        float: left;
        margin: 0;
        padding: 9px 0 7px;
        ul {
          top: -15px;
          padding: 55px 25px 8px 20px;
        }
      }
      .mobile_header_top_bar {
        background: #eeeeee;
        padding: 4px 23px;
      }
      .header_socials a {
        margin: 5px 30px 5px 0;
        &:first-child {
          margin: 5px 30px 5px 0;
        }
        &:last-child {
          margin: 0;
        }
      }
      .logo_wrapper {
        position: relative;
        background: #fff;
        padding: 22px 35px 30px 41px;
        .logo {
          float: left;
        }
      }
      .header_info {
        background: $stm_base_color;
      }
      .icon_texts {
        padding: 40px 40px;
      }
      .header_info .icon_text {
        padding: 0;
        color: #aaaaaa;
        display: inline-block;
        vertical-align: top;
        margin-right: 70px;
        &:last-child {
          margin: 0;
        }
        .text {
          strong {
            color: #fff;
            a {
              color: #fff;
              font-size: 15px;
            }
          }
          span {
            font-size: 13px;
          }
        }
      }
    }
    .icon_text .text {
      float: left;
    }
    .mobile_header .header_info .icon_text .icon {
      width: 32px;
      margin: 0;
    }
    #menu_toggle {
      position: relative;
      cursor: pointer;
      float: right;
      width: 26px;
      height: 20px;
      padding: 10px 0;
      margin: 17px 0 0;
      button {
        position: absolute;
        left: 0;
        top: 50%;
        margin: -2px 0 0;
        background: $stm_base_color;
        height: 4px;
        padding: 0;
        border: none;
        width: 100%;
        -webkit-transition: 0.3s;
        -moz-transition: 0.3s;
        -o-transition: 0.3s;
        transition: 0.3s;
        outline: none !important;
        @include border-radius(2px);
        &:before {
          content: '';
          position: absolute;
          left: 0;
          top: -8px;
          width: 26px;
          height: 4px;
          background: $stm_base_color;
          -webkit-transform-origin: 1.5px center;
          -moz-transform-origin: 1.5px center;
          -o-transform-origin: 1.5px center;
          transform-origin: 1.5px center;
          -webkit-transition: 0.3s;
          -moz-transition: 0.3s;
          -o-transition: 0.3s;
          transition: 0.3s;
          @include border-radius(2px);
        }
        &:after {
          content: '';
          position: absolute;
          left: 0;
          bottom: -8px;
          width: 26px;
          height: 4px;
          background: $stm_base_color;
          -webkit-transform-origin: 1.5px center;
          -moz-transform-origin: 1.5px center;
          -o-transform-origin: 1.5px center;
          transform-origin: 1.5px center;
          -webkit-transition: 0.3s;
          -moz-transition: 0.3s;
          -o-transition: 0.3s;
          transition: 0.3s;
          @include border-radius(2px);
        }
      }
      &.open button {
        background: transparent;
        &:before {
          top: 0;
          -webkit-transform: rotate3d(0, 0, 1, -45deg);
          -moz-transform: rotate3d(0, 0, 1, -45deg);
          -o-transform: rotate3d(0, 0, 1, -45deg);
          transform: rotate3d(0, 0, 1, -45deg);
          -webkit-transform-origin: 50% 50%;
          -moz-transform-origin: 50% 50%;
          -o-transform-origin: 50% 50%;
          transform-origin: 50% 50%;
        }
        &:after {
          bottom: 0;
          transform: rotate3d(0, 0, 1, 45deg);
          transform-origin: 50% 50%;
        }
      }
    }
    .mobile_header .top_nav_mobile {
      padding: 16px 0;
      margin: 0 0 15px;
      display: none;
      box-shadow: 0 0 5px rgba(0, 0, 0, 0.52);
      .main_menu_nav {
        padding: 0;
        margin: 0;
        li {
          position: relative;
          list-style: none;
        }
        > li {
          > a {
            padding: 11px 36px 11px 44px;
            display: block;
            font-size: 20px;
            color: #ffffff;
            text-transform: lowercase;
            font-weight: 700;
            letter-spacing: -0.04em;
          }
          &:hover {
            & > a{
              color: $stm_third_color;
            }
          }
          &.menu-item-has-children {
            .arrow {
              position: absolute;
              display: block;
              right: 12px;
              top: 0;
              cursor: pointer;
              height: 50px;
              padding: 0 30px;
              @include transition();
              &.active {
                -moz-transform: rotate(45deg);
                -ms-transform: rotate(45deg);
                -webkit-transform: rotate(45deg);
                -o-transform: rotate(45deg);
                transform: rotate(45deg);
                i{
                  &:before, &:after{
                    background: $stm_third_color;
                  }
                }
              }
              i{
                position: absolute;
                left: 50%;
                top: 50%;
                transform: translate(-50%,-50%);
                -moz-transform: translate(-50%,-50%);
                -webkit-transform: translate(-50%,-50%);
                width: 11px;
                height: 11px;
                &:before{
                  content: '';
                  position: absolute;
                  left: 0;
                  top: 4px;
                  width: 11px;
                  height: 3px;
                  background: #fff;
                  @include border-radius(1px);
                }
                &:after{
                  content: '';
                  position: absolute;
                  left: 4px;
                  top: 0;
                  width: 3px;
                  height: 11px;
                  background: #fff;
                  @include border-radius(1px);
                }
              }
            }
            > .sub-menu > li.menu-item-has-children .arrow {
              padding: 10px 20px 12px;
            }
          }
        }
        ul {
          position: relative;
          margin: 0;
          padding: 0;
          display: none;
          background: #f0f2f5;
          &:before{
            content: '';
            position: absolute;
            right: 31px;
            top: 0;
            border-left: 10px solid transparent;
            border-right: 10px solid transparent;
            border-top: 8px solid $stm_base_color;
          }
          li {
            text-transform: capitalize;
            .arrow{
              display: none !important;
            }
            a {
              font-size: 16px;
              color: $stm_base_color;
              font-weight: 600;
              padding: 11px 36px 11px 44px;
              display: block;
            }
            &:active > a {
              color: $stm_third_color;
            }
            ul{
              display: block;
              background: #fff;
              &:before{
                display: none;
              }
              a{
                font-size: 14px;
                font-weight: 400;
              }
              li{
                position: relative;
                padding: 0 0 0 7px;
                &:before{
                  content: '';
                  position: absolute;
                  left: 44px;
                  top: 50%;
                  width: 4px;
                  height: 1px;
                  background: $stm_base_color;
                }
              }
            }
          }
        }
        li {
          &.current_page_item > a, &.current-menu-parent > a, &.current-menu-ancestor > a {
            color: $stm_third_color;
          }
        }
        > li.current_page_item.menu-item-has-children > .arrow {
          color: $stm_base_color;
        }
        > li {
          &.current-menu-parent.menu-item-has-children > .arrow, &.current-menu-ancestor.menu-item-has-children > .arrow, &.current-menu-parent.menu-item-has-children > .sub-menu > li.current-menu-item.menu-item-has-children > .arrow, &.current-menu-ancestor.menu-item-has-children > .sub-menu > li.current-menu-parent.menu-item-has-children > .arrow {
            color: $stm_base_color;
          }
        }
      }
    }
    .mobile_menu > ul ul ul {
      display: block;
    }
  }
}

@media only screen and (max-width: 991px) {
  body.header_style_6 {
    .header_top {
      .header_top_wrapper {
        padding: 0 10px;
      }
      .top_nav {
        .top_nav_wrapper {
          > ul {
            margin-right: -10px;
            > li {
              > a {
                font-size: 12px;
                padding: 10px;
              }

              &.menu-item-has-children > a:after {
                right: -2px;
                top: 14px;
              }
            }
          }
        }
      }
    }

    .top_bar_contacts {
      clear: both;
      padding-top: 0;
      > li {
        margin-right: 10px;
      }
    }
  }
  body.header_style_5 {
    .top_nav .top_nav_wrapper {
      > ul > li {
        > a {
          padding: 20px 15px;
        }

        &.menu-item-has-children > a:after {
          right: 0;
        }
      }
    }
  }
  body.header_style_4 {
    .header_top {
      .icon_text.big,
      .icon_text {
        margin-left: 0;
        .icon {
          margin-right: 10px;
        }
        .text {
          font-size: 12px;
        }
      }
    }

    .top_nav {
      .top_nav_wrapper > ul > li {
        > a {
          padding-left: 10px;
          padding-right: 10px;
        }

        &.menu-item-has-children > a:after {
          right: -2px;
        }
      }
    }
  }

  .icon_box.style_2  {
    &.alignment_center {
      text-align: left;
    }
    h5 {
      br {
        display: none;
      }
    }
  }

  .stm_works_wr.style_2 {
    .works_filter {
      li {
        a {
          padding: 12px 13px 10px 13px;
        }

        &:not(:first-child) {
          margin-left: 10px;
        }
      }
    }
  }

  .stm_works_wr {
    &.grid {
      &.style_2 {
        .stm_works {
          .item {
            width: 50%;

            .image {
              a {
                img {
                  width: 100%;
                }
              }
            }
          }
        }
      }
    }
  }

  .testimonials_carousel {
    &.style_3 {
      .testimonial_inner {
        .image {
          float: none;
          width: 100%;
          margin-bottom: 15px;
          margin-right: 0;
        }
      }
    }
  }

}

@media only screen and (max-width: 960px) {
  .header_socials {
    margin: 0 0 0 10px;
  }
  .top_nav .icon_text {
    display: none;
  }
  .vc_column_container.left_column {
    padding-right: 15px !important;
  }
  .header_top .icon_text {
    margin: 5px 0 0 10px;
  }
  .vc_column_container {
    &.right_column {
      padding-left: 15px !important;
    }
    &.center_column {
      padding-left: 15px !important;
      padding-right: 15px !important;
    }
  }
}

@media only screen and (max-width: 768px) {
  .stm_contacts_widget {
    &.style_3 {
      ul li {
        display: block;
        margin-bottom: 20px;
      }
    }
  }
  body .vc_call_to_action {
    padding: 16px 30px 15px 30px;
  }
  .projects_tabs {
    h2 {
      float: none;
      margin: 0 0 30px;
    }
    .tabs {
      float: none;
      margin: 0;
    }
  }
  #header {
    .header_top, .top_nav {
      display: none;
    }
  }
  .mobile_header {
    display: block;
    .header_socials {
      margin: 0;
      float: right;
    }
    #stm_wpml_lang_switcher {
      float: left;
      margin: 0;
      padding: 9px 0 7px;
      ul {
        top: -15px;
        padding: 55px 25px 8px 20px;
      }
    }
    .mobile_header_top_bar {
      background: #eeeeee;
      padding: 4px 23px;
    }
    .header_socials a {
      margin: 5px 30px 5px 0;
      &:first-child {
        margin: 5px 30px 5px 0;
      }
      &:last-child {
        margin: 0;
      }
    }
    .logo_wrapper {
      position: relative;
      background: #fff;
      padding: 22px 35px 30px 41px;
      .logo {
        float: left;
      }
    }
    .header_info {
      background: $stm_base_color;
    }
    .icon_texts {
      padding: 40px 40px;
    }
    .header_info .icon_text {
      padding: 0;
      color: #aaaaaa;
      display: inline-block;
      vertical-align: top;
      margin-right: 70px;
      &:last-child {
        margin: 0;
      }
      .text {
        strong {
          color: #fff;
          a {
            color: #fff;
            font-size: 15px;
          }
        }
        span {
          font-size: 13px;
        }
      }
    }
  }
  .icon_text .text {
    float: left;
  }
  .mobile_header .header_info .icon_text .icon {
    width: 32px;
    margin: 0;
  }
  #menu_toggle {
    position: relative;
    cursor: pointer;
    float: right;
    width: 26px;
    height: 20px;
    padding: 10px 0;
    margin: 17px 0 0;
    button {
      position: absolute;
      left: 0;
      top: 50%;
      margin: -2px 0 0;
      background: $stm_base_color;
      height: 4px;
      padding: 0;
      border: none;
      width: 100%;
      -webkit-transition: 0.3s;
      -moz-transition: 0.3s;
      -o-transition: 0.3s;
      transition: 0.3s;
      outline: none !important;
      @include border-radius(2px);
      &:before {
        content: '';
        position: absolute;
        left: 0;
        top: -8px;
        width: 26px;
        height: 4px;
        background: $stm_base_color;
        -webkit-transform-origin: 1.5px center;
        -moz-transform-origin: 1.5px center;
        -o-transform-origin: 1.5px center;
        transform-origin: 1.5px center;
        -webkit-transition: 0.3s;
        -moz-transition: 0.3s;
        -o-transition: 0.3s;
        transition: 0.3s;
        @include border-radius(2px);
      }
      &:after {
        content: '';
        position: absolute;
        left: 0;
        bottom: -8px;
        width: 26px;
        height: 4px;
        background: $stm_base_color;
        -webkit-transform-origin: 1.5px center;
        -moz-transform-origin: 1.5px center;
        -o-transform-origin: 1.5px center;
        transform-origin: 1.5px center;
        -webkit-transition: 0.3s;
        -moz-transition: 0.3s;
        -o-transition: 0.3s;
        transition: 0.3s;
        @include border-radius(2px);
      }
    }
    &.open button {
      background: transparent;
      &:before {
        top: 0;
        -webkit-transform: rotate3d(0, 0, 1, -45deg);
        -moz-transform: rotate3d(0, 0, 1, -45deg);
        -o-transform: rotate3d(0, 0, 1, -45deg);
        transform: rotate3d(0, 0, 1, -45deg);
        -webkit-transform-origin: 50% 50%;
        -moz-transform-origin: 50% 50%;
        -o-transform-origin: 50% 50%;
        transform-origin: 50% 50%;
      }
      &:after {
        bottom: 0;
        transform: rotate3d(0, 0, 1, 45deg);
        transform-origin: 50% 50%;
      }
    }
  }
  .mobile_header .top_nav_mobile {
    padding: 16px 0;
    margin: 0 0 15px;
    display: none;
    box-shadow: 0 0 5px rgba(0, 0, 0, 0.52);
    .main_menu_nav {
      padding: 0;
      margin: 0;
      li {
        position: relative;
        list-style: none;
      }
      > li {
        > a {
          padding: 11px 36px 11px 44px;
          display: block;
          font-size: 20px;
          color: #ffffff;
          text-transform: lowercase;
          font-weight: 700;
          letter-spacing: -0.04em;
        }
        &:hover {
          & > a{
            color: $stm_third_color;
          }
        }
        &.menu-item-has-children {
          .arrow {
            position: absolute;
            display: block;
            right: 12px;
            top: 0;
            cursor: pointer;
            height: 50px;
            padding: 0 30px;
            @include transition();
            &.active {
              -moz-transform: rotate(45deg);
              -ms-transform: rotate(45deg);
              -webkit-transform: rotate(45deg);
              -o-transform: rotate(45deg);
              transform: rotate(45deg);
              i{
                &:before, &:after{
                  background: $stm_third_color;
                }
              }
            }
            i{
              position: absolute;
              left: 50%;
              top: 50%;
              transform: translate(-50%,-50%);
              -moz-transform: translate(-50%,-50%);
              -webkit-transform: translate(-50%,-50%);
              width: 11px;
              height: 11px;
              &:before{
                content: '';
                position: absolute;
                left: 0;
                top: 4px;
                width: 11px;
                height: 3px;
                background: #fff;
                @include border-radius(1px);
              }
              &:after{
                content: '';
                position: absolute;
                left: 4px;
                top: 0;
                width: 3px;
                height: 11px;
                background: #fff;
                @include border-radius(1px);
              }
            }
          }
          > .sub-menu > li.menu-item-has-children .arrow {
            padding: 10px 20px 12px;
          }
        }
      }
      ul {
        position: relative;
        margin: 0;
        padding: 0;
        display: none;
        background: #f0f2f5;
        &:before{
          content: '';
          position: absolute;
          right: 31px;
          top: 0;
          border-left: 10px solid transparent;
          border-right: 10px solid transparent;
          border-top: 8px solid $stm_base_color;
        }
        li {
          text-transform: capitalize;
          .arrow{
            display: none !important;
          }
          a {
            font-size: 16px;
            color: $stm_base_color;
            font-weight: 600;
            padding: 11px 36px 11px 44px;
            display: block;
          }
          &:active > a {
            color: $stm_third_color;
          }
          ul{
            display: block;
            background: #fff;
            &:before{
              display: none;
            }
            a{
              font-size: 14px;
              font-weight: 400;
            }
            li{
              position: relative;
              padding: 0 0 0 7px;
              &:before{
                content: '';
                position: absolute;
                left: 44px;
                top: 50%;
                width: 4px;
                height: 1px;
                background: $stm_base_color;
              }
            }
          }
        }
      }
      li {
        &.current_page_item > a, &.current-menu-parent > a, &.current-menu-ancestor > a {
          color: $stm_third_color;
        }
      }
      > li.current_page_item.menu-item-has-children > .arrow {
        color: $stm_base_color;
      }
      > li {
        &.current-menu-parent.menu-item-has-children > .arrow, &.current-menu-ancestor.menu-item-has-children > .arrow, &.current-menu-parent.menu-item-has-children > .sub-menu > li.current-menu-item.menu-item-has-children > .arrow, &.current-menu-ancestor.menu-item-has-children > .sub-menu > li.current-menu-parent.menu-item-has-children > .arrow {
          color: $stm_base_color;
        }
      }
    }
  }
  .mobile_menu > ul ul ul {
    display: block;
  }
  .footer_widgets_wrapper .widgets.cols_4 aside {
    width: 50%;
  }
  .vc_row.construction_slider .ls-container {
    margin-top: -60px !important;
  }
  .posts_grid .post_date {
    display: none;
  }
  .page_404 {
    text-align: center;
    h2:before {
      display: none;
    }
    strong {
      margin-top: 250px;
    }
  }
  .contact_col aside.widget {
    padding-top: 70px !important;
    padding-bottom: 44px !important;
  }
  .entry-header {
    margin-top: -60px;
  }
  body.header_style_transparent {
    .icon_text .text strong, .header_top .icon_text span, .header_socials a {
      color: #aaa;
    }
    #header {
      height: auto;
      &:before {
        display: none;
      }
    }
  }
  .top_bar {
    display: none;
  }
  body {
    &.header_style_dark .logo, &.header_style_white .logo {
      margin: 0 !important;
    }
    &.mobile_header_style_white {
      .mobile_header {
        .logo_wrapper {
          background: #3f3f3f;
        }
        .header_info {
          background: #fff;
        }
      }
      #menu_toggle {
        button {
          background: #fff;
          &:before, &:after {
            background: #fff;
          }
        }
        &.open button {
          background: transparent;
        }
      }
      .mobile_header {
        .header_info .icon_text .text strong {
          color: #3f3f3f;
          a {
            color: #3f3f3f;
          }
        }
        .top_nav_mobile .main_menu_nav {
          > li > a {
            color: #3f3f3f;
          }
          li {
            &.current_page_item > a, &.current-menu-parent > a {
              color: $stm_base_color;
            }
          }
          > li.current_page_item.menu-item-has-children .arrow {
            color: $stm_base_color;
          }
          > li {
            &.current-menu-parent.menu-item-has-children .arrow {
              color: $stm_base_color;
            }
            border-bottom: 1px solid #ccc;
            &:hover {
              background: #fff;
            }
          }
          ul li a {
            color: #777;
          }
          > li > a:hover {
            color: $stm_base_color;
          }
        }
      }
    }
    .testimonials_carousel.disable_carousel {
      &.per_row_2{
        .testimonial{
          .image{
            float: none;
            max-width: inherit;
            margin: 0 0 20px;
          }
          .company{
            margin-bottom: 14px;
          }
        }
      }
    }
  }
  .stm_works_wr.cols_4 .stm_works .item,
  .stm_works_wr.cols_3 .stm_works .item,
  .stm_works_wr.cols_2 .stm_works .item{
    width: 50%;
  }
  .woocommerce{
    ul.products {
      clear: both;
      @include cleaner();

      li.product {
        float: left;
        display: table-cell;
        vertical-align: top;
        margin: -1px 0 0;
        padding: 40px 20px;
        position: relative;
        width: 50%;
        border: none;
        border: 1px solid #f2f2f2;
        border-right-color: transparent;
        border-bottom-color: transparent;
        @include transition();
        &:hover {
          @include box-shadow(0, 5px, 20px, 0, rgba(#000, .15));
          border-color: #f2f2f2;
          border-top-color: transparent;
          border-bottom-color: transparent;
        }
        &.first{
          border-left-color: #f2f2f2;
        }
        &.last{
          border-right-color: transparent;
        }
        &:first-child + li.product + li.product{
          border-top-color: #f2f2f2;
        }
        &:first-child, &:first-child + li.product {
          border-top-color: transparent;
        }
        &:nth-child(odd){
          border-left-color: transparent;
        }
        &:nth-child(even){
          border-right-color: transparent;
        }
      }

    }
  }
  .woocommerce .woocommerce-result-count, .woocommerce-page .woocommerce-result-count{
    float: none;
    margin: 0 0 20px;
    padding: 0;
  }
  .woocommerce .woocommerce_before_shop_loop .woocommerce-result-count{
    padding: 0;
  }
  .woocommerce .woocommerce-ordering, .woocommerce-page .woocommerce-ordering{
    float: none;
    margin: 0 0 10px;
    padding: 0;
  }
  .woocommerce .woocommerce_before_shop_loop{
    padding-bottom: 20px;
  }
  .woocommerce ul.products li.product a img{
    max-width: 175px;
  }
  .woocommerce div.product div.images img, .woocommerce #content div.product div.images img{
    max-width: 175px;
  }
  .info_box.style_3 .info_box_text{
    top: 0;
  }
  .info_box.style_3 .info_box_text .title .icon{
    display: none;
  }
  .info_box.style_3 .info_box_text p{
    line-height: 16px;
    margin-bottom: 15px;
  }

  body.header_transparent #header{
    position: relative;
    left: auto;
    top: auto;
    right: auto;
  }

  .stm_services_tabs {
    .service_tab_item {
      padding: 0 15px;

      .service_label {
        left: 15px;
      }
    }
  }

  .stm_gmap_wrapper .gmap_addresses .addresses .item {
    border-right: none;
    padding-right: 30px;
  }

  .testimonials_carousel {
    &.style_3 {
      .testimonial_inner {
        .image {
          float: left;
          width: 174px;
          margin-bottom: 0;
          margin-right: 20px;
        }
      }
    }
  }
}

@media only screen and (max-width: 667px) {
  .stm_services_tabs .service_tab_item {
    width: 100%;
  }
  .stm_partner.style_2 .image{
    float: none;
    max-width: inherit;
    margin: 0 0 20px;
  }
  #frontend_customizer{
    display: none !important;
  }
  body .vc_call_to_action {
    &.vc_cta_btn_pos_right .vc_button-2-wrapper {
      float: none;
      margin: 0 0 20px;
    }
    padding-top: 25px;
    text-align: center;
  }
  .posts_grid > ul > li {
    width: 50%;
  }
  .stm_post_details ul li {
    float: none;
    &.post_by {
      clear: both;
      margin: 0;
      &:before {
        display: none;
      }
    }
  }
  .stm_share {
    text-align: left;
    margin: 10px 0;
  }
  #header {
    margin-bottom: 15px;
  }
  .page_404 strong {
    font-size: 100px;
    margin-top: 20px;
    line-height: 100px;
  }
  .mobile_header .header_info .icon_text {
    display: block;
    margin: 0 0 17px;
  }
  .project_grid .project {
    width: 50%;
  }
  .project_grid_wrapper {
    &.col_2 .project_grid .project, &.col_4 .project_grid .project, &.col_5 .project_grid .project {
      width: 50%;
    }
    &.col_1 .project_grid .project {
      width: 100%;
    }
  }
  .project_grid_filter ul li {
    margin: 1px 10px 10px 0;
  }
  body.header_transparent.header_style_transparent #header {
    position: relative;
    left: auto;
    top: auto;
    height: auto;
    margin-bottom: 0;
  }
  .entry-header {
    .entry-title-right, .entry-title-left {
      float: none;
      height: auto;
      margin: 0 0 20px;
    }
    &.small {
      .entry-title-left, .entry-title-right {
        float: none;
        height: auto;
        margin: 0 0 20px;
      }
    }
    .entry-title-right, &.small .entry-title-right {
      margin-bottom: 30px;
    }
    margin-top: -15px;
  }
  .prev_next_post a {
    margin: 0 12px 0 0;
  }
  .entry-header .entry-title-right .button {
    margin: 0 10px 0 0;
  }

  body .vc_cta3.vc_cta3-actions-right .vc_cta3-content{
    width: auto;
    text-align: center;
    margin: 0 0 20px;
    .vc_custom_heading{
      text-align: center;
    }
  }

  body .vc_general.vc_btn3.vc_btn3-color-theme_style_2.vc_btn3-style-flat{
    display: inline-block;
    width: auto;
  }

  body{
    .vc_btn3-container.vc_btn3-right{
      text-align: center;
    }
  }

  .stats_counter{
    text-align: center;
  }

  .testimonials_carousel .testimonial .image{
    float: none;
    margin: 0 0 20px;
    max-width: inherit;
  }

  .stm_news .news_list li{
    width: 100%;
  }

  #footer .copyright_row .copyright_row_wr {
    .socials{
      width: 100%;
      float: none;
      text-align: center;
      ul{
        float: none;
        display: inline-block;
        vertical-align: top;
      }
    }
    .copyright{
      width: 100%;
      float: none;
      text-align: center;
    }
  }

  #header{
    margin-bottom: 0;
  }

  .page_title.disable_title{
    padding-top: 25px;
  }

  .vacancy_table_wr .vacancy_table thead th.location,
  .vacancy_table_wr .vacancy_table tbody td.location,
  .vacancy_table_wr .vacancy_table thead th:after{
    display: none;
  }

  .vacancy_table_wr .vacancy_table thead th,
  .vacancy_table_wr .vacancy_table tbody td{
    padding-left: 20px;
  }

  .about_vacantion{
    display: block;
    .info{
      display: block;
      padding: 0;
      margin: 0 0 20px;
    }
  }

  .vacancy_bottom{
    .media-body{
      display: block;
      width: auto;
      margin: 0 0 20px;
    }
    .share_buttons{
      display: block;
    }
  }

  .staff_list ul li .staff_image{
    float: none;
    margin: 0 0 30px;
    max-width: inherit;
  }

  .staff_list.grid ul li{
    display: block;
    width: 100%;
  }

  .stm_news .news_list.posts_per_row_3 li,
  .stm_news .news_list.posts_per_row_2 li{
    width: 100%;
  }

  .staff_bottom_wr .staff_bottom .infos{
    display: block;
    .info{
      display: block;
      padding: 0;
      margin: 0 0 30px;
    }
  }

  .staff_bottom_wr{
    padding: 40px 30px;
  }

  .stm_services .item{
    width: 100%;
    display: block;
  }

  .stm_services .item .item_wr .item_thumbnail img{
    width: 100%;
  }

  body .stm_chart canvas{
    height: auto !important;
  }

  .stm_works_wr.grid.style_2 .stm_works .item,
  .stm_works_wr.cols_4 .stm_works .item,
  .stm_works_wr.cols_3 .stm_works .item,
  .stm_works_wr.cols_2 .stm_works .item{
    width: 100%;
  }

  .stm_works_wr.grid .stm_works .item .item_wr:hover .category{
    bottom: 30px;
  }
  .stm_works_wr.grid .stm_works .item .item_wr:hover .title{
    bottom: 60px;
  }

  .stm_works_wr {
    &.style_1 {
      .works_filter li{
        float: none;
        width: 100%;
        margin: 0 0 20px;
        text-align: center;
      }
    }
    &.style_2 {
      .works_filter {
        .works_filter_switcher {
          float: none;
          display: inline-block;

          .stm_works_grid_switcher {
            float: none;
            display: inline-block;
          }
        }

        li {
          float: none;
          width: 100%;
          text-align: center;
          margin: 0 0 20px;

          &:not(:first-child) {
            margin-left: 0;
          }
        }
      }
    }
  }

  .vc_custom_heading.text_align_right{
    & > *{
      text-align: left !important;
      &:after{
        margin-left: 0;
      }
    }
  }

  .vc_tta-color-grey.vc_tta-style-classic .vc_tta-panel .vc_tta-panel-heading{
    h4{
      padding: 0;
      font-weight: 700;
      font-family: "Montserrat", sans-serif;
      text-transform: lowercase;
      font-size: 14px;
      &:after{
        display: none;
      }
    }
  }

  body .vc_tta-container .vc_tta.vc_general.vc_tta-tabs.theme_style .vc_tta-panels .vc_tta-panel-body{
    padding: 20px;
  }

  body{
    .vc_tta-color-grey.vc_tta-style-classic .vc_tta-panel.vc_active .vc_tta-panel-title>a{
      background: $stm_third_color;
      color: $stm_base_color;
    }
  }

  .stm_post_details ul li.post_cat {
    clear: both;
    margin: 0;
    &:before {
      display: none;
    }
  }

  .stm_post_details ul{
    float: none;
  }

  .stm_post_details{
    margin: 0 0 15px;
  }

  .post_bottom .tags{
    width: auto;
    display: block;
    margin: 0 0 30px;
  }
  .post_bottom .share_buttons{
    width: auto;
    display: block;
  }

  .stm_testimonials.cols_4 .item,
  .stm_testimonials.cols_3 .item,
  .stm_testimonials.cols_2 .item{
    width: 100%;
  }

  .woocommerce{
    ul.products {
      clear: both;
      @include cleaner();

      li.product {
        float: left;
        display: block;
        vertical-align: top;
        margin: -1px 0 0;
        padding: 40px 20px;
        position: relative;
        width: 100%;
        border: none !important;
        border-top: 1px solid #f2f2f2 !important;
        border-right-color: transparent;
        border-bottom-color: transparent;
        @include transition();
        &:hover {
          @include box-shadow(0, 5px, 20px, 0, rgba(#000, .15));
          border-color: #f2f2f2;
          border-top-color: transparent;
          border-bottom-color: transparent;
        }
        &:first-child{
          border: none !important;
        }
      }

    }
  }

  .woocommerce div.product div.images, .woocommerce #content div.product div.images{
    width: auto;
    float: none;
    margin: 0 0 30px;
  }

  .woocommerce div.product div.summary, .woocommerce #content div.product div.summary{
    margin: 0 0 30px;
    padding: 0;
  }

  .woocommerce div.product .woocommerce-tabs ul.tabs li a{
    padding-left: 25px;
    padding-right: 25px;
  }

  .woocommerce .woocommerce-message, .woocommerce .woocommerce-error, .woocommerce .woocommerce-info{
    padding-right: 40px !important;
    .wc-forward{
      display: none;
    }
  }

  .woocommerce-cart table.cart td.actions .coupon .input-text{
    float: none;
    width: 100%;
    margin: 0 0 15px;
  }
  .woocommerce-cart table.cart td.actions .coupon button{
    width: 100%;
    float: none;
  }
  .woocommerce-cart table.cart td.actions .button{
    width: 100%;
  }

  .woocommerce table.cart td.actions .coupon{
    padding-bottom: 15px;
  }

  .woocommerce-cart .cart-collaterals .cart_totals{
    width: auto;
    float: none;
  }

  .login .button{
    margin: 0 0 30px;
  }

  .woocommerce form .form-row-first,
  .woocommerce form .form-row-last,
  .woocommerce-page form .form-row-last,
  .woocommerce-checkout-review-order .woocommerce-checkout-review-order-table-wr,
  .woocommerce-checkout-review-order .woocommerce-checkout-payment-wr{
    float: none;
    width: 100%;
  }

  .woocommerce input.button{
    width: 100%;
  }

  .stm_contacts_widget ul.socials li{
    margin-right: 6px;
  }

  .info_box.style_3 .info_box_text .title .icon{
    display: table-cell;
  }

  .info_box.style_3 .info_box_text{
    padding: 17px 30px 0;
  }

  .info_box.style_3 .info_box_text p{
    margin: 0 0 20px;
    color: #fff;
    padding-left: 0;
    font-size: 13px;
    line-height: 24px;
  }

  .testimonials_carousel.disable_carousel {
    &.per_row_2, &.per_row_3{
      .testimonial{
        width: 100%;
      }
    }
  }

}

@media only screen and (max-width: 640px) {
  .vc_testimonials {
    &.style_3 {
      &.navigation-arrows {
        .vc_testimonials_carousel_wr {
          padding: {
            top: 45px;
            left: 40px;
            right: 40px;
            bottom: 65px;
          }
          &:before {
            top: -15px;
            left: 10px;
          }
        }
        .owl-nav {
          bottom: 5px;
          right: 5px;
        }
      }
    }
  }
}

@media only screen and (max-width: 480px) {
  .footer_widgets_wrapper .widgets {
    &.cols_3 aside, &.cols_4 aside {
      width: 100%;
    }
  }
  #footer {
    .footer_widgets {
      .widget {
        &.widget_text {
          #sb_instagram {
            #sbi_images {
              .sbi_item {
                width: 50%;
              }
            }
          }
        }
      }
    }
  }
  .posts_grid {
    > ul > li {
      width: 100%;
    }
    .post_date {
      display: inline-block;
    }
  }
  .stm_post_details {
    .comments_num {
      clear: both;
      float: none;
    }
    ul li {
      &.post_date, &.post_by, &.post_cat {
        margin: 0 0 10px;
      }
    }
  }
  .ls-l.mobile_remove {
    display: none !important;
  }
  .page_404 strong {
    margin-top: 100px;
  }
  .stm_post_details {
    ul {
      width: auto;
    }
    .comments_num {
      text-align: left;
      width: auto;
    }
  }
  .vc_grid-item.blog {
    margin: 0 0 40px;
  }
  .our_partners .logo {
    float: none;
    margin: 0 0 30px;
    display: inline-block;
  }
  .testimonials_carousel.style_3 {
    .testimonial_inner {
      .image {
        float: none;
        width: 100%;
        margin-bottom: 15px;
        margin-right: 0;
      }
    }
  }
  .stm_services_tabs {
    .services_categories {
      ul li {
        float: none;
      }
    }
  }
}

@media only screen and (max-height: 700px) {
  body.header_style_7 {
    .header_side_wrapper {
      padding-top: 39px;
    }
    .side_nav {
      margin-top: 32px;
    }
    .header_socials {
      margin-top: 25px;
    }
  }
}