.stm_contacts_widget{
  color: #fff;
  font-family: "Montserrat", sans-serif;
  h4{
    position: relative;
    color: #fff;
    padding: 0;
  }
  ul{
    position: relative;
    list-style: none;
    padding: 0;
    margin: 0 0 30px;
    li{
      color: #fff;
      padding: 0;
      margin: 0 0 13px;
      line-height: 22px;
      &:before{
        display: none;
      }
      .icon{
        float: left;
        font-size: 20px;
        line-height: 18px;
        color: $stm_third_color;
        margin: 0 15px 0 0;
        .fa-envelope{
          font-size: 16px;
          line-height: 22px;
        }
      }
      .text{
        overflow: hidden;
        padding: 1px 0 0;
        font-weight: 500;
      }
    }
  }
  ul.socials{
    @include cleaner();
    margin: 0;
    li{
      float: left;
      margin: 0 8px 8px 0;
      &:last-child{
        margin-right: 0;
      }
      a{
        display: block;
        width: 32px;
        height: 32px;
        @include border-radius(32px);
        background: #fff;
        text-align: center;
        line-height: 32px;
        color: $stm_base_color;
        font-size: 17px;
        text-decoration: none !important;
        @include transition();
        i{
          line-height: 34px;
          &.fa-vimeo{
            font-size: 14px;
          }
          &.stm-google-plus{
            font-size: 13px;
          }
        }
        &:hover{
          background: $stm_secondary_color;
          color: #fff;
        }
        &.social-facebook:hover{
          background: #3a5897;
        }
        &.social-twitter:hover{
          background: #00aced;
        }
        &.social-instagram:hover{
          background: #ac907a;
        }
        &.social-google-plus:hover{
          background: #db4437;
        }
        &.social-linkedin:hover{
          background: #0077b5;
        }
        &.social-skype:hover{
          background: #00aff0;
        }
      }
    }
  }
}

.stm_contacts_widget.style_2 {
  ul {
    margin-bottom: -13px;
    @include cleaner();
    li {
      float: left;
      &:not(:last-child) {
        margin-right: 54px;
      }
      .icon {
        float: none;
        display: inline-block;
        vertical-align: middle;
        width: 39px;
        background: $stm_third_color;
        text-align: center;
        line-height: 39px;
        color: #fff;
      }

      .text {
        display: inline-block;
        font-size: 14px;
        vertical-align: middle;
        color: $stm_base_color;
      }
    }
  }
}

.stm_contacts_widget.style_3 {
  font-family: "Open Sans", sans-serif;
  ul {
    text-align: center;
    font-size: 0;
    margin-bottom: 0;
    list-style: none;
    li {
      padding: 0 17px;
      display: inline-block;
      vertical-align: top;
      font-size: 13px;

      .icon {
        float: none;
        min-height: 25px;
        margin: 0 0 17px;
        font-size: 19px;

        &:before {
          content: "";
          display: inline-block;
          width: 1px;
          height: 0;
          vertical-align: bottom;
        }

        i {
          vertical-align: bottom;
        }

        .stm-envelope-11 {
          font-size: 16px;
        }

        .stm-clock6,
        .stm-pin-11 {
          font-size: 20px;
        }
      }

      .text {
        padding: 0;
        line-height: 18px;
        font-weight: 400;
        color: rgba(#fff, .5);

        a {
          color: #fff;
        }
      }
    }
  }
}