.stm_partner{
  position: relative;
  .image{
    border: 3px solid #f2f2f2;
    margin: 0 0 24px;
    img{
      display: block;
      max-width: 100%;
      height: auto;
    }
  }
  h5, h4{
    line-height: normal;
    padding: 0;
    margin: 0 0 5px;
    a{
      color: $stm_base_color;
      @include transition();
      &:hover{
        color: $stm_third_color;
        text-decoration: none;
      }
    }
  }
  .description{
    font-size: 13px;
    line-height: 18px;
    margin-bottom: 15px;
  }
  .read_more {
    text-transform: lowercase;
    font-weight: 700;
    font-size: 13px;
    transition: color 0.2s linear;
    color: #222222;
    .stm_icon {
      margin: 2px 0 0 5px;
      font-size: 12px;
      vertical-align: middle;
      color: $stm_third_color;
    }
    span {
      vertical-align: middle;
      line-height: 13px;
    }
    &:hover {
      color: $stm_secondary_color;
      text-decoration: none;
    }
  }
  &.style_2{
    @include cleaner();
    .image{
      float: left;
      max-width: 203px;
      margin: 0 33px 0 0;
      border: none;
      box-shadow: 0 2px 7px rgba(0, 0, 0, 0.17);
      -moz-box-shadow: 0 2px 7px rgba(0, 0, 0, 0.17);
      -webkit-box-shadow: 0 2px 7px rgba(0, 0, 0, 0.17);
    }
    .stm_partner_content{
      overflow: hidden;
      h4{
        color: $stm_base_color;
        margin: 0 0 13px;
      }
      .position{
        color: #777777;
        letter-spacing: -0.04em;
        font-family: "Montserrat", sans-serif;
        margin: 0 0 17px;
        line-height: 18px;
      }
      .description{
        border-top: 1px solid #dddddd;
        padding-top: 13px;
        line-height: 22px;
        margin: 0;
      }
    }
  }
}