.wpb_content_element {
  ul {
    margin: 0 0 20px;
    list-style: none;
    padding: 0;
    li{
      position: relative;
      padding: 0 0 0 26px;
      margin: 0 0 9px;
      line-height: 22px;
      color: #222222;
      &:before {
        content: "\f04d";
        @include fa();
        position: absolute;
        left: 0;
        top: 8px;
        display: inline-block;
        vertical-align: top;
        font-size: 5px;
        color: $stm_secondary_color;
        transform: rotate(45deg);
      }
    }
  }
  strong {
    color: #333333;
  }
}

body .vc_call_to_action.vc_cta_btn_pos_right .vc_button-2-wrapper{
  float: right;
}

body .vc_call_to_action.vc_cta_btn_pos_left .vc_button-2-wrapper{
  float: left;
}

body .vc_call_to_action.vc_cta_btn_pos_right .vc_cta_btn,
body .vc_call_to_action.vc_cta_btn_pos_left .vc_cta_btn
{
  float: none;
  margin: 0;
}

body .vc_call_to_action hgroup h2, body .vc_call_to_action h4{
  font-size: 18px;
  line-height: 24px;
  font-weight: 700;
  padding: 11px 0;
  color: #fff;
}

body .vc_call_to_action hgroup h2:before, body .vc_call_to_action h4:before{
  display: none;
}

body .vc_call_to_action {
  background-color: $stm_base_color;
  background-image: url( "../../images/stroke.png" );
  background-repeat: repeat;
  border: none;
  padding: 16px 30px 15px 55px;
}

body .vc_call_to_action.stretch{
  margin-left: -3000px;
  margin-right: -3000px;
  padding-right: 3000px;
  padding-left: 3000px;
}

@media all and (-webkit-min-device-pixel-ratio: 1.5) {
  body .vc_call_to_action {
    background-image: url('../../images/stroke@2x.png');
    background-size: 8px 8px;
  }
}

body .vc_btn,
body a.vc_btn,
body button.vc_btn,
body .vc_btn:hover,
body a.vc_btn:hover,
body button.vc_btn:hover,
body .vc_btn:focus,
body a.vc_btn:focus,
body button.vc_btn:focus{
  text-decoration: none !important;
  border: none;
  padding: 16px 22px 14px;
  border-radius: 0;
  font-size: 13px;
  line-height: 15px;
  font-weight: 900;
  display: inline-block;
  box-shadow: none !important;
  outline: none !important;
  color: #4c4c4b;
  white-space: nowrap;
  transition: background 0.2s linear, color 0.2s linear;
}

body .vc_btn-sm,
body a.vc_btn-sm,
body button.vc_btn-sm{
  padding: 13px 22px 11px !important;
}

body .vc_call_to_action a.vc_btn{
  position: relative;
  padding-right: 40px;
  background: #fff;
}

body .vc_call_to_action a.vc_btn:after{
  content: '\f054';
  position: absolute;
  right: 13px;
  top: 13px;
  font: normal normal normal 14px/1 FontAwesome;
  font-size: 20px;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  transform: translate(0, 0);
  color: $stm_base_color;
}

body .vc_call_to_action a.vc_btn:hover,
body .vc_call_to_action a.vc_btn:active,
body .vc_call_to_action a.vc_btn:focus{
  color: #fff;
  background: #333;
}

body .wpb_image_grid .wpb_image_grid_ul .isotope-item{
  margin: 0 15px 15px 0;
}

body .wpb_image_grid .wpb_image_grid_ul{
  width: 110%;
}

.wpb_gallery h5:before{
  display: none;
}

.wpb_gallery h5{
  margin: 0 0 30px 0;
}

body .vc_separator.type_2{
  background: url("../../images/pattern_3.png") repeat-x 0 0;
  background-size: 8px 5px;
  height: 5px;
}

.wpb_widgetised_column aside.widget{
  margin: 0 0 40px 0;
}

.vc_grid-item.services .vc_gitem-post-data-source-post_image h2:before{
  display: none;
}

.vc_grid-item.services .vc_gitem-post-data-source-post_image img{
  height: 196px;
  width: auto;
}

.vc_grid-item.services .vc_gitem-post-data-source-post_title{
  text-transform: uppercase;
}

.vc_grid-item.services .vc_gitem-post-data-source-post_title a{
  color: #333333;
}

.vc_grid-item.services .vc_gitem-post-data-source-post_title a:hover{
  color: $stm_base_color;
}

.vc_grid-item.services .vc_gitem-post-data-source-post_title > *:before{
  background: #cbcbcb;
}

.vc_grid-item.services:hover .vc_gitem-post-data-source-post_title > *:before{
  background: $stm_base_color;
}

.vc_grid-item.services .vc_gitem-post-data-source-post_title > *{
  margin: 0;
}

.vc_grid-item.services .vc_grid-item-mini{
  padding-bottom: 45px;
  background: url("../../images/pattern_3.png") repeat-x -5px 100%;
}

.post_grid_no_pattern .vc_grid-item.services .vc_grid-item-mini,
.post_grid_no_pattern
{
  background: none;
  padding-bottom: 0;
}

body .vc_grid.vc_grid-gutter-30px .vc_grid-item{
  padding-bottom: 40px;
  display: inline-block;
  float: none;
  vertical-align: top;
}

.vc_grid.vc_row .vc_grid-item.services .wpb_content_element,
.vc_grid.vc_row .vc_grid-item.services .vc_icon_element,
.vc_grid.vc_row .vc_grid-item.services .vc_btn{
  margin: 0;
}

body .vc_btn-orange,
body a.vc_btn-orange,
body button.vc_btn-orange{
  background: $stm_base_color;
}

body .vc_btn-orange:hover,
body a.vc_btn-orange:hover,
body button.vc_btn-orange:hover{
  background: #777777;
}

body .vc_grid.vc_row .vc_grid-item .vc_grid-item-mini{
  position: relative;
}

body .vc_grid.vc_row .vc_grid-item{
  padding-bottom: 40px !important;
}

.vc_grid.vc_row .vc_grid-item.vc_col-sm-4:nth-child(-n+3) .vc_grid-item-mini:before{
  display: none;
}

.vc_grid.vc_row .vc_grid-item.vc_col-sm-4:nth-child(-n+3) .vc_grid-item-mini{
  padding-top: inherit;
}

.vc_grid.vc_row .vc_grid-item.vc_col-sm-2:nth-child(-n+6) .vc_grid-item-mini:before{
  display: none;
}

.vc_grid.vc_row .vc_grid-item.vc_col-sm-2:nth-child(-n+6) .vc_grid-item-mini{
  padding-top: inherit;
}

.vc_grid.vc_row .vc_grid-item.vc_col-sm-3:nth-child(-n+4) .vc_grid-item-mini:before{
  display: none;
}

.vc_grid.vc_row .vc_grid-item.vc_col-sm-3:nth-child(-n+4) .vc_grid-item-mini{
  padding-top: inherit;
}

.vc_grid.vc_row .vc_grid-item.vc_col-sm-6:nth-child(-n+2) .vc_grid-item-mini:before{
  display: none;
}

.vc_grid.vc_row .vc_grid-item.vc_col-sm-6:nth-child(-n+2) .vc_grid-item-mini{
  padding-top: inherit;
}

.vc_grid.vc_row .vc_grid-item.vc_col-sm-12:first-child .vc_grid-item-mini:before{
  display: none;
}

.vc_grid.vc_row .vc_grid-item.vc_col-sm-12:first-child .vc_grid-item-mini{
  padding-top: inherit;
}

body .wpb_video_widget .wpb_wrapper .wpb_video_wrapper{
  padding-top: 0;
}

body .wpb_video_widget .wpb_wrapper .wpb_video_wrapper img{
  max-width: 100%;
  height: auto;
}

body .wpb_video_widget .wpb_wrapper .wpb_video_wrapper .play_video{
  position: absolute;
  top: 50%;
  left: 50%;
  width: 65px;
  height: 65px;
  border: 5px solid $stm_third_color;
  background: $stm_third_color;
  opacity: 0.9;
  margin: -32px 0 0 -32px;
  @include transition();
}

body .wpb_video_widget .wpb_wrapper .wpb_video_wrapper .play_video:after{
  content: '';
  position: absolute;
  top: 16px;
  left: 21px;
  border-top: 11px solid transparent;
  border-bottom: 11px solid transparent;
  border-right: 15px solid transparent;
  border-left: 15px solid #222;
}

body .wpb_video_widget .wpb_wrapper .wpb_video_wrapper .play_video:hover{
  opacity: 1;
}

body .wpb_video_widget .wpb_wrapper .wpb_video_wrapper .play_video:hover:after{
  border-left-color: #fff;
}

body .wpb_gmaps_widget .wpb_wrapper{
  padding: 0;
  background: none;
}

body .vc_grid.vc_row.vc_grid-gutter-40px .vc_grid-item {
  padding-right: 40px;
  padding-bottom: 40px;
}

body .vc_grid.vc_row.vc_grid-gutter-45px .vc_grid-item {
  padding-right: 45px;
  padding-bottom: 45px;
}

body .vc_grid.vc_row.vc_grid-gutter-50px .vc_grid-item {
  padding-right: 50px;
  padding-bottom: 50px;
}

body .vc_grid.vc_row.vc_grid-gutter-55px .vc_grid-item {
  padding-right: 55px;
  padding-bottom: 55px;
}

body .vc_grid.vc_row.vc_grid-gutter-60px .vc_grid-item {
  padding-right: 60px;
  padding-bottom: 60px;
}

body .vc_grid.vc_row.vc_grid-gutter-40px .vc_pageable-slide-wrapper{
  margin-right: -40px;
}

body .vc_grid.vc_row.vc_grid-gutter-45px .vc_pageable-slide-wrapper{
  margin-right: -45px;
}

body .vc_grid.vc_row.vc_grid-gutter-50px .vc_pageable-slide-wrapper{
  margin-right: -50px;
}

body .vc_grid.vc_row.vc_grid-gutter-55px .vc_pageable-slide-wrapper{
  margin-right: -55px;
}

body .vc_grid.vc_row.vc_grid-gutter-60px .vc_pageable-slide-wrapper{
  margin-right: -60px;
}


body .vc_column_container .vc_btn,
body .vc_column_container .wpb_button,
body .vc_grid.vc_row .vc_grid-item .vc_btn{
  margin: 0;
}

.vc_gitem-post-data-source-post_date:before{
  content: "\f017";
  display: inline-block;
  vertical-align: middle;
  margin: 0 7px 0 0;
  font: normal normal normal 15px/1 FontAwesome;
  font-size: inherit;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  transform: translate(0, 0);
  color: $stm_base_color;
}

.vc_gitem-post-data-source-post_date > *{
  display: inline-block;
  vertical-align: middle;
  color: #aaaaaa;
  font-size: 12px;
}

body .vc_btn3.vc_btn3-color-orange,
body .vc_btn3.vc_btn3-color-orange.vc_btn3-style-flat{
  background-color: $stm_base_color;
}

body .vc_btn3.vc_btn3-size-md.vc_btn3-icon-right:not(.vc_btn3-o-empty){
  padding-right: 40px;
}

body .vc_btn3.vc_btn3-size-md{
  font-size: 13px;
}

body .vc_btn3.vc_btn3-color-orange:hover,
body .vc_btn3.vc_btn3-color-orange.vc_btn3-style-flat:hover,
body .vc_btn3.vc_btn3-color-orange:focus,
body .vc_btn3.vc_btn3-color-orange.vc_btn3-style-flat:focus{
  color: #fff;
  background: #333;
}

.vc_col-sm-3.wpb_column .pricing_price_wrap {
  font-size: 35px;
}

.vc_col-sm-3.wpb_column .pricing_price_wrap,
.vc_col-sm-3.wpb_column .pricing-table_content,
.vc_col-sm-3.wpb_column .pricing-table_footer {
  padding: 0;
}

body .vc_message_box {
  text-transform: uppercase;
  font-weight: 900;
  padding: 1.8em 1em 1.8em 3em;
  color: #777777;
  margin: 0 0 30px 0;
}

body .vc_message_box-icon > .fa {
  font-size: 16px;
}

body .vc_color-info.vc_message_box,
body .vc_color-danger.vc_message_box,
body .vc_color-warning.vc_message_box,
body .vc_color-success.vc_message_box {
  color: #777777;
}

body .vc_message_box-outline,
body .vc_message_box-solid-icon {
  border-width: 4px;
}

body .vc_color-info.vc_message_box-outline,
body .vc_color-info.vc_message_box-solid-icon {
  border-color: #99bcdb;
}

body .vc_color-danger.vc_message_box-outline,
body .vc_color-danger.vc_message_box-solid-icon {
  border-color: #ffb3b3;
}

body .vc_color-warning.vc_message_box-outline,
body .vc_color-warning.vc_message_box-solid-icon {
  border-color: #f9d7a3;
}

body .vc_color-success.vc_message_box-outline,
body .vc_color-success.vc_message_box-solid-icon {
  border-color: #bee0a8;
}

body .vc_color-info.vc_message_box .vc_message_box-icon,
body .vc_color-info.vc_message_box-outline .vc_message_box-icon,
body .vc_color-info.vc_message_box-solid-icon .vc_message_box-icon {
  color: #337ab7;
}

body .vc_color-danger.vc_message_box .vc_message_box-icon,
body .vc_color-danger.vc_message_box-outline .vc_message_box-icon,
body .vc_color-danger.vc_message_box-solid-icon .vc_message_box-icon {
  color: #ff6868;
}

body .vc_color-warning.vc_message_box-outline .vc_message_box-icon,
body .vc_color-warning.vc_message_box-solid-icon .vc_message_box-icon,
body .vc_color-warning.vc_message_box .vc_message_box-icon {
  color: #f3b047;
}

body .vc_color-success.vc_message_box-outline .vc_message_box-icon,
body .vc_color-success.vc_message_box-solid-icon .vc_message_box-icon,
body .vc_color-success.vc_message_box .vc_message_box-icon {
  color: #7ec251;
}

body .vc_progress_bar .vc_label {
  font-size: 14px;
  color: #aaaaaa;
  display: block;
  margin-bottom: 12px;
}

body .vc_progress_bar .vc_single_bar {
  height: 6px;
  background: #dbdbdb;
  border-radius: 0;
  -webkit-box-shadow: none;
  box-shadow: none;
}

body .vc_progress_bar .vc_single_bar .vc_bar {
  border-radius: 0;
}

body .vc_progress_bar .vc_single_bar .vc_bar.striped {
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(-45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  -webkit-background-size: 40px 40px;
  -moz-background-size: 40px 40px;
  -o-background-size: 40px 40px;
  background-size: 40px 40px;
}

/*
	Progress bar style
	.style_1, .style_2
	stripped .vc_single_bar
*/
body .vc_progress_bar.style_1 .vc_single_bar,
body .vc_progress_bar.style_2 .vc_single_bar {
  background: -webkit-repeating-linear-gradient(135deg, #fff, #fff 25%, #e3e3e3 25%, #e3e3e3 50%, #fff 50%) top left fixed;
  background: repeating-linear-gradient(-45deg, #fff, #fff 25%, #e3e3e3 25%, #e3e3e3 50%, #fff 50%) top left fixed;
  background-size: 4px 4px;
}

body .vc_progress_bar.style_2 .vc_bar_value-marker {
  position: absolute;
  right: 0;
  bottom: 15px;
  line-height: 1;
  background-color: #dbdbdb;
  color: #626262;
  font-size: 10px;
  padding: 2px;
  -webkit-transform: translateX(50%);
  transform: translateX(50%);
}

body .vc_progress_bar.style_2 .vc_bar_value-marker:after {
  content: "";
  position: absolute;
  top: 100%;
  left: 0;
  right: 0;
  height: 0;
  width: 0;
  margin: 0 auto;
  border: 3px solid transparent;
  border-top: 3px solid #dbdbdb;
}

body .vc_btn3.vc_btn3-color-grey.vc_btn3-style-outline {
  color: #aaaaaa;
  border-color: #acacac;
}

body .vc_btn3.vc_btn3-color-grey.vc_btn3-style-outline:hover,
body .vc_btn3.vc_btn3-color-grey.vc_btn3-style-outline:focus {
  background-color: $stm_base_color;
  border-color: $stm_base_color;
  color: #ffffff;
}

.wpb_content_element .dropcarps_bordered:first-letter {
  float: left;
  border: 6px solid $stm_base_color;
  color: $stm_base_color;
  font-size: 28px;
  font-weight: 900;
  padding: 15.5px 17px;
  margin: 6px 25px 15px 0;
}

.wpb_content_element .dropcarps:first-letter {
  float: left;
  color: #aaaaaa;
  font-size: 28px;
  font-weight: 900;
  padding: 21.5px 23px;
  margin: 6px 25px 15px 0;
}

.wpb_content_element ol li {
  margin: 0 0 10px 0;
}

.wpb_content_element ol {
  padding: 0;
  list-style-position: inside;
}

.wpb_content_element ul.style_1 li,
ul.style_1 li,
.wpb_content_element ul.style_2 li,
ul.style_2 li,
.wpb_content_element ul.style_3 li,
ul.style_3 li,
.wpb_content_element ul.style_4 li,
ul.style_4 li,
.wpb_content_element ul.style_5 li,
ul.style_5 li {
  padding: 0 0 0 27px;
  margin: 0 0 10px 0;
  position: relative;
  list-style: none;
}

.wpb_content_element ul.style_1 li:last-child,
ul.style_1 li:last-child,
.wpb_content_element ul.style_2 li:last-child,
ul.style_2 li:last-child,
.wpb_content_element ul.style_3 li:last-child,
ul.style_3 li:last-child,
.wpb_content_element ul.style_4 li:last-child,
ul.style_4 li:last-child,
.wpb_content_element ul.style_5 li:last-child,
ul.style_5 li:last-child {
  margin-bottom: 0;
}

.wpb_content_element ul.style_1 li:before,
ul.style_1 li:before,
.wpb_content_element ul.style_2 li:before,
ul.style_2 li:before,
.wpb_content_element ul.style_3 li:before,
ul.style_3 li:before,
.wpb_content_element ul.style_4 li:before,
ul.style_4 li:before,
.wpb_content_element ul.style_5 li:before,
ul.style_5 li:before {
  content: "\f054";
  position: absolute;
  left: 0;
  top: 3px;
  display: inline-block;
  vertical-align: top;
  font: normal normal normal 14px/1 FontAwesome;
  color: $stm_base_color;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  transform: translate(0, 0)
}

/*
	style_1 - check
	style_2 - square check
	style_3 - circle o
	style_4 - plus
	style_5 - arrow_right
*/

.wpb_content_element ul.style_1 li:before,
ul.style_1 li:before {
  content: "\f00c";
}

.wpb_content_element ul.style_2 li:before,
ul.style_2 li:before {
  content: "\f14a";
}

.wpb_content_element ul.style_3 li:before,
ul.style_3 li:before {
  content: "\f10c";
  color: #777777;
}

.wpb_content_element ul.style_4 li:before,
ul.style_4 li:before {
  content: "\f067";
}

.wpb_content_element ul.style_5 li:before,
ul.style_5 li:before {
  content: "\f061";
  color: #777777;
}

body .wpb_tour_next_prev_nav {
  display: none;
}

.vc_row.buttons-group .vc_btn3-container.vc_btn3-inline {
  margin-right: 12px;
}

.vc_row.buttons-group .vc_btn3-container.vc_btn3-inline:last-child {
  margin-right: 0;
}

.stm_pricing-table {
  background-color: #f6f6f6;
  border: 5px solid #f6f6f6;
  padding: 35px;
  position: relative;
  -webkit-transition: all 0.3s linear;
  transition: all 0.3s linear;
  text-align: center;
}

.pricing-table_inner {
  display: inline-block;
  text-align: left;
}

.stm_pricing-table.has-label {
  background-color: #ffffff;
  border-color: #cccccc;
}

.pricing-table_head {
  margin: 0 0 23px 0;
}

.pricing-table_head h5:before {
  margin-bottom: 18px;
}

.pricing-table_head h5 {
  margin: 0 0 29px 0;
}

.pricing_price_wrap {
  font-size: 40px;
  line-height: 1;
  color: #333333;
  padding: 0 20px;
}

.pricing_price_prefix,
.pricing_price {
  font-weight: 900;
}

.pricing_price_separator,
.pricing_price_postfix {
  font-weight: 300;
}

.pricing-table_content {
  padding: 0 20px;
}

.pricing-table_content ol,
.pricing-table_content ul {
  padding: 0;
  margin: 0;
  list-style-position: inside;
}

.pricing-table_content ul {
  list-style: none;
}

.pricing-table_content ol li,
.pricing-table_content ul li {
  padding-left: 26px;
  position: relative;
  margin: 0 0 7px 0;
}

.pricing-table_content ol li:last-child,
.pricing-table_content ul li:last-child {
  margin-bottom: 0;
}

.pricing-table_content ul li:before {
  content: "\f00c";
  position: absolute;
  left: 0;
  top: 3px;
  display: inline-block;
  vertical-align: top;
  font: normal normal normal 13px/1 FontAwesome;
  color: $stm_base_color;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  transform: translate(0, 0);
}

.pricing-table_footer {
  margin: 32px 0 0 0;
  padding: 0 20px;
}

.vc_col-sm-3.wpb_column .pricing_price_wrap {
  font-size: 35px;
}

.vc_col-sm-3.wpb_column .pricing_price_wrap,
.vc_col-sm-3.wpb_column .pricing-table_content,
.vc_col-sm-3.wpb_column .pricing-table_footer {
  padding: 0;
}

.pricing-table_label {
  position: absolute;
  top: -5px;
  right: -11px;
  background-color: #cccccc;
  color: #ffffff;
  text-transform: uppercase;
  font-size: 13px;
  font-weight: 900;
  line-height: 1;
  padding: 10px 13px;
}

.pricing-table_label:after {
  content: "";
  position: absolute;
  top: 100%;
  right: 0;
  border: 2px solid transparent;
  border-left: 5px solid #b0b0b0;
  border-top: 1px solid #b0b0b0;
}

.wpb_content_element img{
  max-width: 100%;
  height: auto;
}

body .vc_grid-container{
  margin-bottom: 0;
}

body .vc_grid.vc_row .vc_grid-item.no_margins{
  padding-bottom: 0 !important;
}

body .wpb_button, body .wpb_column > .vc_column-inner > .wpb_wrapper > :last-child {
  margin-bottom: 0;
}

body{
  .wpb_button, .wpb_column>.vc_column-inner >.wpb_wrapper>:last-child{
    margin-bottom: 0;
  }
  .vc_col-has-fill>.vc_column-inner, .vc_row-has-fill+.vc_row-full-width+.vc_row>.vc_column_container>.vc_column-inner, .vc_row-has-fill+.vc_row>.vc_column_container>.vc_column-inner, .vc_row-has-fill+.vc_vc_row>.vc_row>.vc_vc_column>.vc_column_container>.vc_column-inner, .vc_row-has-fill+.vc_vc_row_inner>.vc_row>.vc_vc_column_inner>.vc_column_container>.vc_column-inner, .vc_row-has-fill>.vc_column_container>.vc_column-inner, .vc_row-has-fill>.vc_row>.vc_vc_column>.vc_column_container>.vc_column-inner, .vc_row-has-fill>.vc_vc_column_inner>.vc_column_container>.vc_column-inner{
    padding-top: 0;
  }
}

@import "stm_info_box";
@import "stm_projects";
@import "stm_icon_box";
@import "stm_testimonials";
@import "stm_stats_counter";
@import "stm_posts_grid";
@import "stm_project_details";
@import "stm_project_grid";
@import "stm_partner";
@import "stm_staff_list";
@import "stm_contact";
@import "stm_vacancies";
@import "stm_testimonials_carousel";
@import "stm_image_carousel";
@import "stm_news";
@import "stm_gmap";
@import "stm_company_history";
@import "stm_contacts_widget";
@import "stm_services";
@import "stm_services_tabs";
@import "stm_chart";
@import "stm_works";
@import "vc_cta3";
@import "vc_btn";
@import "vc_rev_slider";
@import "vc_wp_gallery";
@import "vc_custom_heading";
@import "vc_tta";
